@@ -26,7 +26,7 @@ class Entsoe():
         df = pd.DataFrame(indata_list)
         df = df.pivot_table(index='ts', columns='country', values='price')
         df = df.ffill()
-        df.columns = [f'Spotprice {c}' for c in df.columns]
+        # df.columns = [f'Spotprice {c}' for c in df.columns]
         return df
 
     def dayahead_prices(self, countries, start_date, end_date=datetime(2030, 12, 31)):
